// Don't modify, generated using unocommands.py

var unoCommandsArray = {
	AcceptAllTrackedChanges:{text:{menu:_('Accept All'),},},
	AcceptTrackedChanges:{text:{menu:_('~Manage...'),},},
	AlignBlock:{spreadsheet:{menu:_('Justified'),},},
	AlignHorizontalCenter:{spreadsheet:{menu:_('Align Center'),},text:{menu:_('Center Horizontal'),},},
	AlignLeft:{spreadsheet:{menu:_('Align Left'),},text:{menu:_('Align Left'),},},
	AlignRight:{spreadsheet:{menu:_('Align Right'),},text:{menu:_('Align Right'),},},
	AnchorMenu:{global:{menu:_('Anc~hor'),},},
	ArrangeFrameMenu:{text:{menu:_('Arrange'),},},
	ArrangeMenu:{global:{menu:_('A~rrange'),},presentation:{menu:_('~Arrange'),},},
	AutoFormatMenu:{text:{menu:_('AutoCorr~ect'),},},
	BackColor:{text:{menu:_('Highlight Color'),},},
	BackgroundColor:{global:{menu:_('Background Color'),},},
	Bold:{global:{menu:_('Bold'),},},
	BringToFront:{global:{menu:_('~Bring to Front'),},},
	CenterPara:{global:{context:_('Align Center'),menu:_('Center'),},},
	ChangeCaseRotateCase:{global:{menu:_('Cycle Case'),},},
	ChangeCaseToLower:{global:{menu:_('~lowercase'),},},
	ChangeCaseToSentenceCase:{global:{menu:_('~Sentence case'),},},
	ChangeCaseToTitleCase:{global:{menu:_('~Capitalize Every Word'),},},
	ChangeCaseToToggleCase:{global:{menu:_('~tOGGLE cASE'),},},
	ChangeCaseToUpper:{global:{menu:_('~UPPERCASE'),},},
	ChangesMenu:{global:{menu:_('Track Chan~ges'),},},
	ClearOutline:{global:{menu:_('~Remove Outline'),},},
	ColorScaleFormatDialog:{spreadsheet:{menu:_('Color Scale...'),},},
	CommonAlignBottom:{global:{menu:_('Bottom'),},},
	CommonAlignHorizontalCenter:{global:{menu:_('Centered'),},},
	CommonAlignJustified:{global:{menu:_('Justified'),},},
	CommonAlignLeft:{global:{menu:_('Left'),},},
	CommonAlignRight:{global:{menu:_('Right'),},},
	CommonAlignTop:{global:{menu:_('Top'),},},
	CommonAlignVerticalCenter:{global:{menu:_('Center'),},},
	CondDateFormatDialog:{spreadsheet:{menu:_('Date...'),},},
	ConditionalFormatDialog:{spreadsheet:{menu:_('Condition...'),},},
	ConditionalFormatManagerDialog:{spreadsheet:{menu:_('Manage...'),},},
	ConditionalFormatMenu:{spreadsheet:{menu:_('C~onditional'),},},
	ContinueNumbering:{text:{menu:_('Continue previous numbering'),},},
	ControlCodes:{text:{menu:_('For~matting Marks'),},},
	Copy:{global:{menu:_('Cop~y'),},},
	CopyHyperlinkLocation:{global:{menu:_('Copy Hyperlink Location'),},},
	CustomAnimation:{presentation:{menu:_('Animation'),},},
	Cut:{global:{menu:_('~Cut'),},},
	DataBarFormatDialog:{spreadsheet:{menu:_('Data Bar...'),},},
	DataFilterAutoFilter:{spreadsheet:{menu:_('Auto~Filter'),},},
	DataFilterHideAutoFilter:{spreadsheet:{menu:_('~Hide AutoFilter'),},},
	DataFilterRemoveFilter:{spreadsheet:{menu:_('~Reset Filter'),},},
	DataFilterSpecialFilter:{spreadsheet:{menu:_('~Advanced Filter...'),},},
	DataFilterStandardFilter:{spreadsheet:{menu:_('~Standard Filter...'),},},
	DataMenu:{global:{menu:_('~Data'),},},
	DataRanges:{global:{menu:_('~Data Ranges...'),},},
	DataSort:{spreadsheet:{menu:_('~Sort...'),},},
	DecrementIndent:{global:{context:_('Decrease Indent'),menu:_('Decrease Indent'),},},
	DecrementLevel:{text:{menu:_('Demote One Level'),},},
	DecrementSubLevels:{text:{menu:_('Demote One Level With Subpoints'),},},
	DefaultBullet:{global:{context:_('Toggle Bulleted List'),menu:_('~Bulleted List'),},},
	DefaultNumbering:{global:{context:_('Toggle Numbered List'),menu:_('~Numbered List'),},},
	DelBreakMenu:{spreadsheet:{menu:_('Delete Page ~Break'),},},
	Delete:{global:{menu:_('Delete C~ontents...'),},spreadsheet:{context:_('Cl~ear Contents...'),menu:_('Cle~ar Cells...'),},},
	DeleteAllNotes:{global:{menu:_('Delete All Comments'),},spreadsheet:{menu:_('Delete All Comments'),},},
	DeleteAuthor:{global:{menu:_('Delete All Comments by This Author'),},},
	DeleteAxis:{global:{menu:_('Delete Axis'),},},
	DeleteColumnbreak:{spreadsheet:{menu:_('~Column Break'),},},
	DeleteColumns:{presentation:{menu:_('Delete Column'),},spreadsheet:{menu:_('Delete Columns'),},text:{menu:_('~Columns'),},},
	DeleteComment:{global:{menu:_('Delete Comment'),},},
	DeleteDataLabel:{global:{menu:_('Delete Single Data Label'),},},
	DeleteLegend:{global:{menu:_('Delete Legend'),},},
	DeleteMajorGrid:{global:{menu:_('Delete Major Grid'),},},
	DeleteMinorGrid:{global:{menu:_('Delete Minor Grid'),},},
	DeleteNote:{spreadsheet:{menu:_('Delete Comment'),},},
	DeleteRowbreak:{spreadsheet:{menu:_('~Row Break'),},},
	DeleteRows:{presentation:{menu:_('Delete Row'),},spreadsheet:{menu:_('Delete Rows'),},text:{menu:_('~Rows'),},},
	DeleteSlide:{presentation:{menu:_('~Delete Slide'),},},
	DeleteTable:{text:{menu:_('~Table'),},},
	DiagramData:{global:{menu:_('~Data Table...'),},},
	DiagramType:{global:{menu:_('Chart T~ype...'),},},
	DownSearch:{global:{menu:_('Find Next'),},},
	DuplicateSlide:{presentation:{menu:_('Duplicate ~Slide'),},},
	EditHeaderAndFooter:{spreadsheet:{menu:_('~Headers and Footers...'),},},
	EditMenu:{global:{menu:_('~Edit'),},},
	EditRegion:{text:{menu:_('~Sections...'),},},
	EditStyle:{global:{menu:_('~Edit Style...'),},presentation:{menu:_('E~dit Style...'),},},
	EntireCell:{text:{menu:_('C~ell'),},},
	EntireColumn:{presentation:{menu:_('Select Column'),},text:{menu:_('~Column'),},},
	EntireRow:{presentation:{menu:_('Select Row'),},text:{menu:_('~Row'),},},
	FilterMenu:{spreadsheet:{menu:_('More ~Filters'),},},
	FontColor:{global:{menu:_('Font Color'),},text:{menu:_('Font Color'),},},
	FontDialog:{global:{menu:_('C~haracter...'),},},
	FormatArea:{global:{menu:_('A~rea...'),},},
	FormatAxis:{global:{menu:_('Format Axis...'),},},
	FormatBulletsMenu:{global:{menu:_('Lis~ts'),},},
	FormatCellDialog:{spreadsheet:{context:_('~Format Cells...'),menu:_('Ce~lls...'),},},
	FormatChartArea:{global:{menu:_('Format Chart Area...'),},},
	FormatColumns:{text:{menu:_('Co~lumns...'),},},
	FormatDataLabel:{global:{menu:_('Format Single Data Label...'),},},
	FormatDataLabels:{global:{menu:_('Format Data Labels...'),},},
	FormatDataPoint:{global:{menu:_('Format Data Point...'),},},
	FormatDataSeries:{global:{menu:_('Format Data Series...'),},},
	FormatFloor:{global:{menu:_('Format Floor...'),},},
	FormatLegend:{global:{menu:_('Format Legend...'),},},
	FormatLine:{global:{menu:_('L~ine...'),},},
	FormatMajorGrid:{global:{menu:_('Format Major Grid...'),},},
	FormatMeanValue:{global:{menu:_('Format Mean Value Line...'),},},
	FormatMenu:{global:{menu:_('F~ormat'),},},
	FormatMinorGrid:{global:{menu:_('Format Minor Grid...'),},},
	FormatPaintbrush:{global:{context:_('Clone Formatting (double click for multi-selection)'),menu:_('Clone'),},text:{context:_('Clone Formatting (double click and Ctrl or Cmd to alter behavior)'),menu:_('Clone'),},},
	FormatSelection:{global:{menu:_('Format Selection...'),},},
	FormatSpacingMenu:{global:{menu:_('~Spacing'),},},
	FormatStockGain:{global:{menu:_('Format Stock Gain...'),},},
	FormatStockLoss:{global:{menu:_('Format Stock Loss...'),},},
	FormatTextMenu:{global:{menu:_('Te~xt'),},},
	FormatTitle:{global:{menu:_('Format Title...'),},},
	FormatTrendline:{global:{menu:_('Format Trend Line...'),},},
	FormatTrendlineEquation:{global:{menu:_('Format Trend Line Equation...'),},},
	FormatWall:{global:{menu:_('Format Wall...'),},},
	FormatXErrorBars:{global:{menu:_('Format X Error Bars...'),},},
	FormatYErrorBars:{global:{menu:_('Format Y Error Bars...'),},},
	FormattingMarkMenu:{global:{menu:_('Formatting Mark'),},},
	FullScreen:{global:{menu:_('F~ull Screen'),},},
	GoalSeekDialog:{spreadsheet:{menu:_('~Goal Seek...'),},},
	Group:{global:{menu:_('~Group...'),},},
	GroupOutlineMenu:{spreadsheet:{menu:_('~Group and Outline'),},},
	Grow:{global:{menu:_('Increase Size'),},},
	HeaderAndFooter:{presentation:{menu:_('~Header and Footer...'),},},
	HelpMenu:{global:{menu:_('~Help'),},},
	Hide:{spreadsheet:{menu:_('~Hide Sheet'),},},
	HideColumn:{spreadsheet:{context:_('H~ide Columns'),menu:_('~Hide'),},},
	HideDetail:{global:{menu:_('~Hide Details'),},},
	HideRow:{spreadsheet:{context:_('H~ide Rows'),menu:_('H~ide'),},},
	HyperlinkDialog:{global:{context:_('Insert Hyperlink'),menu:_('~Hyperlink...'),},},
	IconSetFormatDialog:{spreadsheet:{menu:_('Icon Set...'),},},
	IncrementIndent:{global:{context:_('Increase Indent'),menu:_('Increase Indent'),},},
	IncrementLevel:{text:{menu:_('Promote One Level'),},},
	IncrementSubLevels:{text:{menu:_('Promote One Level With Subpoints'),},},
	IndexesMenu:{text:{menu:_('Table of Contents and Inde~x'),},},
	InsertAnnotation:{global:{context:_('Insert Comment'),menu:_('Comme~nt'),},presentation:{menu:_('Comme~nt'),},spreadsheet:{context:_('Insert Co~mment'),menu:_('Comm~ent'),},},
	InsertAuthorField:{presentation:{menu:_('~Author'),},text:{menu:_('First ~Author'),},},
	InsertAuthoritiesEntry:{text:{menu:_('~Bibliography Entry...'),},},
	InsertAxis:{global:{menu:_('Insert Axis'),},},
	InsertAxisTitle:{global:{menu:_('Insert Axis Title'),},},
	InsertBreakMenu:{spreadsheet:{menu:_('Insert Page ~Break'),},},
	InsertColumnBreak:{spreadsheet:{menu:_('~Column Break'),},text:{menu:_('Insert Column Break'),},},
	InsertColumnsAfter:{presentation:{menu:_('Insert Column After'),},spreadsheet:{context:_('Insert Columns ~After'),menu:_('Columns ~After'),},text:{menu:_('Columns ~After'),},},
	InsertColumnsBefore:{presentation:{menu:_('Insert Column Before'),},spreadsheet:{context:_('Insert Columns ~Before'),menu:_('Columns ~Before'),},text:{menu:_('Columns ~Before'),},},
	InsertColumnsMenu:{spreadsheet:{menu:_('Insert Co~lumns'),},},
	InsertCurrentDate:{spreadsheet:{menu:_('~Date'),},},
	InsertCurrentTime:{spreadsheet:{menu:_('~Time'),},},
	InsertDataLabel:{global:{menu:_('Insert Single Data Label'),},},
	InsertDateField:{text:{menu:_('~Date'),},},
	InsertDateFieldFix:{presentation:{menu:_('~Date (fixed)'),},},
	InsertDateFieldVar:{presentation:{menu:_('Dat~e (variable)'),},},
	InsertEndnote:{text:{menu:_('~Endnote'),},},
	InsertField:{text:{menu:_('~More Fields...'),},},
	InsertFootnote:{text:{menu:_('~Footnote'),},},
	InsertGraphic:{global:{context:_('Insert Image...'),menu:_('~Image...'),},},
	InsertHardHyphen:{global:{menu:_('Insert non-br~eaking hyphen'),},},
	InsertHeaderFooterMenu:{text:{menu:_('He~ader and Footer'),},},
	InsertIndexesEntry:{text:{menu:_('~Index Entry...'),},},
	InsertLRM:{global:{menu:_('~Left-to-right Mark'),},},
	InsertMajorGrid:{global:{menu:_('Insert Major Grid'),},},
	InsertMeanValue:{global:{menu:_('Insert Mean ~Value Line'),},},
	InsertMenu:{global:{menu:_('~Insert'),},},
	InsertMinorGrid:{global:{menu:_('Insert Minor Grid'),},},
	InsertMultiIndex:{text:{menu:_('Table of Contents, ~Index or Bibliography...'),},},
	InsertNeutralParagraph:{text:{menu:_('Insert Unnumbered Entry'),},},
	InsertNonBreakingSpace:{global:{menu:_('Insert ~non-breaking space'),},},
	InsertObjectChart:{global:{context:_('Insert Chart'),menu:_('~Chart...'),},},
	InsertPageCountField:{text:{menu:_('Page ~Count'),},},
	InsertPageFooter:{text:{menu:_('Foote~r'),},},
	InsertPageHeader:{text:{menu:_('He~ader'),},},
	InsertPageNumberField:{global:{menu:_('~Page Numbers...'),},text:{menu:_('~Page Number'),},},
	InsertPagebreak:{text:{menu:_('~Page Break'),},},
	InsertRLM:{global:{menu:_('~Right-to-left Mark'),},},
	InsertRemoveAxes:{global:{menu:_('Insert/Delete Axes...'),},},
	InsertRowBreak:{spreadsheet:{menu:_('~Row Break'),},},
	InsertRowsAfter:{presentation:{menu:_('Insert Row Below'),},spreadsheet:{context:_('Insert Rows ~Below'),menu:_('Rows ~Below'),},text:{menu:_('Rows ~Below'),},},
	InsertRowsBefore:{presentation:{menu:_('Insert Row Above'),},spreadsheet:{context:_('Insert Rows ~Above'),menu:_('Rows ~Above'),},text:{menu:_('Rows ~Above'),},},
	InsertRowsMenu:{spreadsheet:{menu:_('Insert ~Rows'),},},
	InsertSection:{text:{menu:_('Se~ction...'),},},
	InsertSlide:{presentation:{menu:_('~New Slide'),},},
	InsertSlideField:{presentation:{menu:_('~Slide Number'),},},
	InsertSlideTitleField:{presentation:{menu:_('Slide Tit~le'),},},
	InsertSlidesField:{presentation:{menu:_('Slide ~Count'),},},
	InsertSoftHyphen:{global:{menu:_('Insert s~oft Hyphen'),},},
	InsertSymbol:{global:{context:_('Insert Special Character'),menu:_('S~pecial Character...'),},},
	InsertTable:{presentation:{menu:_('~Table...'),},text:{menu:_('Insert ~Table...'),},},
	InsertTimeField:{global:{menu:_('Time Field'),},text:{menu:_('~Time'),},},
	InsertTimeFieldFix:{presentation:{menu:_('~Time (fixed)'),},},
	InsertTimeFieldVar:{presentation:{menu:_('T~ime (variable)'),},},
	InsertTitleField:{text:{menu:_('T~itle'),},},
	InsertTitles:{global:{menu:_('Insert Titles...'),},},
	InsertTopicField:{text:{menu:_('~Subject'),},},
	InsertTrendline:{global:{menu:_('Insert Tre~nd Line...'),},},
	InsertXErrorBars:{global:{menu:_('Insert X Error ~Bars...'),},},
	InsertYErrorBars:{global:{menu:_('Insert Y Error ~Bars...'),},},
	InsertZWNBSP:{global:{menu:_('No-width No ~Break'),},},
	InsertZWSP:{global:{menu:_('No-~width Optional Break'),},},
	Italic:{global:{menu:_('Italic'),},},
	JumpDownThisLevel:{text:{menu:_('To Next Paragraph in Level'),},},
	JumpUpThisLevel:{text:{menu:_('To Previous Paragraph in Level'),},},
	JustifyPara:{global:{menu:_('Justified'),},},
	LanguageMenu:{global:{menu:_('Language'),},},
	LanguageStatus:{global:{menu:_('Language Status'),},},
	LayoutStatus:{presentation:{menu:_('Layout'),},},
	LeftPara:{global:{context:_('Align Left'),menu:_('Left'),},},
	MasterSlidesPanel:{presentation:{menu:_('Master Slides'),},},
	MergeCells:{presentation:{menu:_('Merge Cells'),},spreadsheet:{menu:_('Merge Cells'),},text:{menu:_('Merge Cells'),},},
	ModifyPage:{presentation:{menu:_('Slide ~Layout'),},},
	MoveDown:{text:{menu:_('Move Down'),},},
	MoveDownSubItems:{text:{menu:_('Move Down with Subpoints'),},},
	MoveUp:{text:{menu:_('Move Up'),},},
	MoveUpSubItems:{text:{menu:_('Move Up with Subpoints'),},},
	NextTrackedChange:{text:{menu:_('Next'),},},
	NumberFormatCurrency:{spreadsheet:{context:_('Format as Currency'),menu:_('Currency'),},text:{menu:_('Number Format: Currency'),},},
	NumberFormatDecDecimals:{spreadsheet:{menu:_('Delete Decimal Place'),},},
	NumberFormatIncDecimals:{spreadsheet:{menu:_('Add Decimal Place'),},},
	NumberFormatPercent:{spreadsheet:{context:_('Format as Percent'),menu:_('Percent'),},text:{menu:_('Number Format: Percent'),},},
	NumberingStart:{text:{menu:_('Restart Numbering'),},},
	ObjectBackOne:{global:{menu:_('Back One'),},},
	ObjectForwardOne:{global:{menu:_('Forward One'),},},
	OnlineAutoFormat:{text:{menu:_('~While Typing'),},},
	OpenHyperlinkOnCursor:{global:{menu:_('Open Hyperlink'),},},
	OutlineBullet:{global:{menu:_('~Bullets and Numbering...'),},},
	OutlineFont:{global:{menu:_('Outline'),},},
	Overline:{global:{menu:_('Overline'),},},
	PageDialog:{global:{menu:_('~Page...'),},text:{menu:_('~Page Style...'),},},
	PageDown:{text:{menu:_('Next Page'),},},
	PageFormatDialog:{spreadsheet:{menu:_('~Page...'),},},
	PageSetup:{presentation:{menu:_('Properties...'),},},
	PageUp:{text:{menu:_('Previous Page'),},},
	ParaLeftToRight:{global:{menu:_('Left-To-Right'),},},
	ParaRightToLeft:{global:{menu:_('Right-To-Left'),},},
	ParagraphDialog:{global:{menu:_('P~aragraph...'),},},
	ParaspaceDecrease:{global:{context:_('Decrease Paragraph Spacing'),menu:_('Decrease Paragraph Spacing'),},},
	ParaspaceIncrease:{global:{context:_('Increase Paragraph Spacing'),menu:_('Increase Paragraph Spacing'),},},
	Paste:{global:{menu:_('~Paste'),},},
	PickList:{global:{menu:_('~File'),},},
	PreviousTrackedChange:{text:{menu:_('Pr~evious'),},},
	Print:{global:{menu:_('~Print...'),},},
	RecalcPivotTable:{spreadsheet:{menu:_('~Refresh'),},},
	Redo:{global:{menu:_('~Redo'),},},
	RejectAllTrackedChanges:{text:{menu:_('Reject All'),},},
	Remove:{spreadsheet:{menu:_('~Delete Sheet...'),},},
	RemoveHyperlink:{global:{menu:_('~Remove Hyperlink'),},},
	RemoveTableOf:{text:{menu:_('Delete index'),},},
	RenameTable:{spreadsheet:{menu:_('Rename S~heet...'),},},
	ReplyComment:{global:{menu:_('Reply Comment'),},},
	ResetAllDataPoints:{global:{menu:_('Reset all Data Points'),},},
	ResetAttributes:{global:{menu:_('~Clear Direct Formatting'),},spreadsheet:{context:_('Clear Direct Formatting'),menu:_('Clear ~Direct Formatting'),},text:{context:_('Clear Direct Formatting'),menu:_('Clear ~Direct Formatting'),},},
	ResetDataPoint:{global:{menu:_('Reset Data Point'),},},
	RightPara:{global:{context:_('Align Right'),menu:_('Right'),},},
	RotateLeft:{text:{menu:_('Rotate 90° ~Left'),},},
	RotateMenu:{global:{menu:_('Rot~ate'),},},
	RotateRight:{text:{menu:_('Rotate 90° ~Right'),},},
	Save:{global:{menu:_('~Save'),},},
	SaveAs:{global:{menu:_('Save ~As...'),},},
	SearchDialog:{global:{menu:_('Find and Rep~lace...'),},},
	SelectAll:{global:{menu:_('Select ~All'),},},
	SelectBackground:{presentation:{menu:_('Set Background Image...'),},},
	SelectTable:{presentation:{menu:_('~Select...'),},text:{menu:_('~Table'),},},
	SendToBack:{global:{menu:_('~Send to Back'),},},
	SetAnchorAtChar:{text:{menu:_('To ~Character'),},},
	SetAnchorToCell:{spreadsheet:{menu:_('To ~Cell'),},},
	SetAnchorToCellResize:{spreadsheet:{menu:_('To Cell (~resize with cell)'),},},
	SetAnchorToChar:{text:{menu:_('As C~haracter'),},},
	SetAnchorToFrame:{text:{menu:_('To ~Frame'),},},
	SetAnchorToPage:{spreadsheet:{menu:_('To P~age'),},text:{menu:_('To P~age'),},},
	SetAnchorToPara:{text:{menu:_('To ~Paragraph'),},},
	SetDefault:{global:{menu:_('Clear ~Direct Formatting'),},},
	SetLanguageAllTextMenu:{global:{menu:_('For All Text'),},},
	SetLanguageParagraphMenu:{global:{menu:_('For Paragraph'),},},
	SetLanguageSelectionMenu:{global:{menu:_('For Selection'),},},
	SetObjectToBackground:{global:{menu:_('To Background'),},},
	SetObjectToForeground:{global:{menu:_('To Foreground'),},},
	SetOptimalColumnWidth:{presentation:{menu:_('Optimal Column Width'),},spreadsheet:{menu:_('~Optimal Width...'),},text:{menu:_('Optimal Column Width'),},},
	SetOptimalRowHeight:{presentation:{menu:_('Optimal Row Height'),},spreadsheet:{menu:_('~Optimal Height...'),},text:{menu:_('Optimal Row Height'),},},
	Shadowed:{global:{menu:_('Shadow'),},},
	ShapesMenu:{global:{menu:_('~Shape'),},},
	SheetMenu:{spreadsheet:{menu:_('~Sheet'),},},
	Show:{spreadsheet:{menu:_('~Show Sheet...'),},},
	ShowColumn:{spreadsheet:{context:_('S~how Columns'),menu:_('~Show'),},},
	ShowDetail:{global:{menu:_('~Show Details'),},},
	ShowNote:{spreadsheet:{menu:_('Show Comment'),},},
	ShowResolvedAnnotations:{text:{menu:_('Resolved Comments'),},},
	ShowRow:{spreadsheet:{context:_('Sho~w Rows'),menu:_('~Show'),},},
	ShowTrackedChanges:{text:{menu:_('~Show'),},},
	Shrink:{global:{menu:_('Decrease Size'),},},
	Sidebar:{global:{menu:_('Sidebar'),},},
	SlideChangeWindow:{presentation:{menu:_('Slide Transition'),},},
	SlideMasterPage:{presentation:{menu:_('~Master Slide'),},},
	SlideMenu:{presentation:{menu:_('S~lide'),},},
	SmallCaps:{global:{menu:_('Small capitals'),},},
	SortAscending:{spreadsheet:{menu:_('Sort Ascending'),},},
	SortDescending:{spreadsheet:{menu:_('Sort Descending'),},},
	SpacePara1:{global:{menu:_('Line Spacing: 1'),},},
	SpacePara15:{global:{menu:_('Line Spacing: 1.5'),},},
	SpacePara2:{global:{menu:_('Line Spacing: 2'),},},
	SpellCheckApplySuggestion:{global:{menu:_('Apply Suggestion'),},},
	SpellCheckIgnore:{global:{menu:_('Ignore'),},},
	SpellCheckIgnoreAll:{global:{menu:_('IgnoreAll'),},},
	SpellDialog:{global:{menu:_('~Spelling...'),},},
	SpellOnline:{global:{menu:_('~Automatic Spell Checking'),},},
	SpellingAndGrammarDialog:{global:{menu:_('~Spelling...'),},},
	SplitCell:{presentation:{menu:_('Split Cells'),},spreadsheet:{menu:_('Split Cells'),},text:{menu:_('Split Cells...'),},},
	Strikeout:{global:{menu:_('Strikethrough'),},},
	SubScript:{global:{menu:_('Subscript'),},text:{menu:_('Subscript'),},},
	SuperScript:{global:{menu:_('Superscript'),},text:{menu:_('Superscript'),},},
	TableDeleteMenu:{global:{menu:_('~Delete'),},},
	TableDialog:{presentation:{menu:_('~Properties...'),},text:{menu:_('~Properties...'),},},
	TableInsertMenu:{global:{menu:_('~Insert'),},},
	TableMenu:{global:{menu:_('T~able'),},},
	TableSelectMenu:{text:{menu:_('~Select'),},},
	TaskPaneInsertPage:{presentation:{menu:_('Insert Slide'),},},
	Text:{global:{context:_('Insert Text Box'),menu:_('~Text Box'),},},
	TextAlign:{global:{menu:_('Alig~n'),},},
	ThesaurusDialog:{global:{menu:_('~Thesaurus...'),},text:{menu:_('~Thesaurus...'),},},
	ToggleMergeCells:{spreadsheet:{menu:_('M~erge and Center Cells'),},},
	ToolsMenu:{global:{menu:_('~Tools'),},},
	TrackChanges:{text:{menu:_('~Record'),},},
	TransformDialog:{global:{menu:_('Position and Si~ze...'),},},
	Underline:{global:{menu:_('Underline'),},},
	UnderlineDouble:{global:{menu:_('Double Underline'),},},
	Undo:{global:{menu:_('~Undo'),},},
	Ungroup:{global:{menu:_('~Ungroup...'),},},
	UpSearch:{global:{menu:_('Find Previous'),},},
	UpdateCurIndex:{text:{context:_('Update index'),menu:_('Current ~Index'),},},
	Validation:{spreadsheet:{menu:_('~Validity...'),},},
	View3D:{global:{menu:_('~3D View...'),},},
	ViewMenu:{global:{menu:_('~View'),},},
	Watermark:{text:{menu:_('Watermark...'),},},
	WordCountDialog:{text:{menu:_('~Word Count...'),},},
	WrapAnchorOnly:{text:{menu:_('~First Paragraph'),},},
	WrapContour:{text:{menu:_('~Contour'),},},
	WrapIdeal:{text:{menu:_('~Optimal Page Wrap'),},},
	WrapLeft:{text:{menu:_('Wrap Left'),},},
	WrapMenu:{text:{menu:_('~Wrap'),},},
	WrapOff:{text:{menu:_('Wrap Off'),},},
	WrapOn:{text:{menu:_('~Page Wrap'),},},
	WrapRight:{text:{menu:_('Wrap Right'),},},
	WrapText:{spreadsheet:{menu:_('Wrap Text'),},},
	WrapThrough:{text:{menu:_('~Wrap Through'),},},
	WrapThroughTransparencyToggle:{text:{menu:_('In ~Background'),},},
	ZoomMinus:{global:{menu:_('Zoom Out'),},},
	ZoomPlus:{global:{menu:_('Zoom In'),},},
};

window._UNO = function(string, component, isContext) {
	var command = string.substr(5);
	var context = 'menu';
	if (isContext === true) {
		context = 'context';
	}
	var entry = unoCommandsArray[command];
	if (entry === undefined) {
		return command;
	}
	var componentEntry = entry[component];
	if (componentEntry === undefined) {
		componentEntry = entry['global'];
		if (componentEntry === undefined) {
			return command;
		}
	}
	var text = componentEntry[context];
	if (text === undefined) {
		text = componentEntry['menu'];
		if (text === undefined) {
			return command;
		}
	}

	return this.removeAccessKey(text);
}

window.removeAccessKey = function(text) {
	// Remove access key markers from translated strings
	// 1. access key in parenthesis in case of non-latin scripts
	text = text.replace(/\(~[A-Za-z]\)/, '');
	// 2. remove normal access key
	text = text.replace('~', '');

	return text;
}
